@@ -1,8 +1,8 @@
+import glob, os, shutil, os, sys
+sys.path.append("synesthesia")
+
 from synesthesia.gui import *
-from synesthesia import *
 from synesthesia.essentia_helper import *
-from synesthesia.image_helper import *
 from synesthesia.lib import *
 from synesthesia.wsl import *
-from synesthesia.images import *
-
+from synesthesia import *
\ No newline at end of file
